EXPORTS
	??0CSyncAction@@IAE@AAVCConsoleBase@@AAVOutput@@@Z @ 1 NONAME ; CSyncAction::CSyncAction(class CConsoleBase &, class Output &)
	??0CTestAction@@IAE@AAVCConsoleBase@@AAVOutput@@@Z @ 2 NONAME ; CTestAction::CTestAction(class CConsoleBase &, class Output &)
	??0ConsoleOutput@@QAE@AAVCConsoleBase@@@Z @ 3 NONAME ; ConsoleOutput::ConsoleOutput(class CConsoleBase &)
	??0FileOutput@@QAE@AAVRFile@@@Z @ 4 NONAME ; FileOutput::FileOutput(class RFile &)
	??0NullOutput@@QAE@XZ @ 5 NONAME ; NullOutput::NullOutput(void)
	??1CErrorConverter@@UAE@XZ @ 6 NONAME ; CErrorConverter::~CErrorConverter(void)
	??1CScriptSetup@@UAE@XZ @ 7 NONAME ; CScriptSetup::~CScriptSetup(void)
	??1CTestAction@@UAE@XZ @ 8 NONAME ; CTestAction::~CTestAction(void)
	??1CTestHandlerSettings@@QAE@XZ @ 9 NONAME ; CTestHandlerSettings::~CTestHandlerSettings(void)
	??1CTestSetup@@UAE@XZ @ 10 NONAME ; CTestSetup::~CTestSetup(void)
	?AddErrorItem@CErrorConverter@@QAEXABVTDesC16@@ABH@Z @ 11 NONAME ; void CErrorConverter::AddErrorItem(class TDesC16 const &, int const &)
	?AddNextTest@CTestSpec@@UAEHPAVCTestAction@@@Z @ 12 NONAME ; int CTestSpec::AddNextTest(class CTestAction *)
	?AfterOOMFailure@CTestAction@@UAEXXZ @ 13 NONAME ; void CTestAction::AfterOOMFailure(void)
	?CheckResult@CTestAction@@UAEXH@Z @ 14 NONAME ; void CTestAction::CheckResult(int)
	?CompareFileL@Utils@@SAHABVTDesC16@@0AAH@Z @ 15 NONAME ; int Utils::CompareFileL(class TDesC16 const &, class TDesC16 const &, int &)
	?ConstructL@CSyncAction@@IAEXABVTTestActionSpec@@@Z @ 16 NONAME ; void CSyncAction::ConstructL(class TTestActionSpec const &)
	?ConstructL@CTestAction@@IAEXABVTTestActionSpec@@@Z @ 17 NONAME ; void CTestAction::ConstructL(class TTestActionSpec const &)
	?CreateActionL@CScriptSetup@@MBEPAVCTestAction@@AAVRFs@@ABVTTestActionSpec@@QBUTScriptTests@@@Z @ 18 NONAME ; class CTestAction * CScriptSetup::CreateActionL(class RFs &, class TTestActionSpec const &, struct TScriptTests const * const) const
	?CreateAndRunTestsL@CTestSetup@@SAXQAUTHardcodedTests@@ABVTDesC16@@@Z @ 19 NONAME ; void CTestSetup::CreateAndRunTestsL(struct THardcodedTests * const, class TDesC16 const &)
	?CreateAndRunTestsL@CTestSetup@@SAXQAUTScriptTests@@ABVTDesC16@@1HPAVCConsoleBase@@PAH@Z @ 20 NONAME ; void CTestSetup::CreateAndRunTestsL(struct TScriptTests * const, class TDesC16 const &, class TDesC16 const &, int, class CConsoleBase *, int *)
	?DoPerformPostrequisite@CTestAction@@EAEXAAVTRequestStatus@@@Z @ 21 NONAME ; void CTestAction::DoPerformPostrequisite(class TRequestStatus &)
	?DoPerformPrerequisite@CTestAction@@EAEXAAVTRequestStatus@@@Z @ 22 NONAME ; void CTestAction::DoPerformPrerequisite(class TRequestStatus &)
	?FailTestNow@CSyncAction@@MAEXAAVTRequestStatus@@@Z @ 23 NONAME ; void CSyncAction::FailTestNow(class TRequestStatus &)
	?FailTestNow@CTestAction@@UAEXAAVTRequestStatus@@@Z @ 24 NONAME ; void CTestAction::FailTestNow(class TRequestStatus &)
	?GetArgument@CTestSetup@@KAPAVHBufC16@@H@Z @ 25 NONAME ; class HBufC16 * CTestSetup::GetArgument(int)
	?GetExpectedResultL@CErrorConverter@@QAEHABHAAPAVHBufC16@@@Z @ 26 NONAME ; int CErrorConverter::GetExpectedResultL(int const &, class HBufC16 * &)
	?GetExpectedResultL@CErrorConverter@@QAEHABVTDesC16@@AAH@Z @ 27 NONAME ; int CErrorConverter::GetExpectedResultL(class TDesC16 const &, int &)
	?GetExpectedResultL@Input@@SAHABHAAPAVHBufC16@@@Z @ 28 NONAME ; int Input::GetExpectedResultL(int const &, class HBufC16 * &)
	?GetExpectedResultL@Input@@SAHABVTDesC16@@AAH@Z @ 29 NONAME ; int Input::GetExpectedResultL(class TDesC16 const &, int &)
	?GetNextTest@CTestSpec@@UAEHAAPAVCTestAction@@@Z @ 30 NONAME ; int CTestSpec::GetNextTest(class CTestAction * &)
	?InitialiseL@CHardcodedSetup@@QAEHAAVRFs@@ABVTDesC16@@@Z @ 31 NONAME ; int CHardcodedSetup::InitialiseL(class RFs &, class TDesC16 const &)
	?InitialiseL@CScriptSetup@@QAEHAAVRFs@@ABVTDesC16@@1H@Z @ 32 NONAME ; int CScriptSetup::InitialiseL(class RFs &, class TDesC16 const &, class TDesC16 const &, int)
	?NewL@CErrorConverter@@SAPAV1@XZ @ 33 NONAME ; class CErrorConverter * CErrorConverter::NewL(void)
	?NewL@CTestHandlerSettings@@SAPAV1@ABV1@@Z @ 34 NONAME ; class CTestHandlerSettings * CTestHandlerSettings::NewL(class CTestHandlerSettings const &)
	?NewL@CTestSpec@@SAPAV1@XZ @ 35 NONAME ; class CTestSpec * CTestSpec::NewL(void)
	?NewLC@CErrorConverter@@SAPAV1@XZ @ 36 NONAME ; class CErrorConverter * CErrorConverter::NewLC(void)
	?NewLC@CHardcodedSetup@@SAPAV1@XZ @ 37 NONAME ; class CHardcodedSetup * CHardcodedSetup::NewLC(void)
	?NewLC@CScriptSetup@@SAPAV1@PAVCConsoleBase@@@Z @ 38 NONAME ; class CScriptSetup * CScriptSetup::NewLC(class CConsoleBase *)
	?NewLC@CTestHandler@@SAPAV1@AAVRFs@@AAVMTestSpec@@AAVCTestHandlerSettings@@PAVCConsoleBase@@PAVOutput@@@Z @ 39 NONAME ; class CTestHandler * CTestHandler::NewLC(class RFs &, class MTestSpec &, class CTestHandlerSettings &, class CConsoleBase *, class Output *)
	?NewLC@CTestHandlerSettings@@SAPAV1@XZ @ 40 NONAME ; class CTestHandlerSettings * CTestHandlerSettings::NewLC(void)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@00@Z @ 41 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@00AAH1@Z @ 42 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@00AAH@Z @ 43 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@0@Z @ 44 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@0AAH1@Z @ 45 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@0AAH@Z @ 46 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@00@Z @ 47 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@00AAH1@Z @ 48 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &, int &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@00AAH@Z @ 49 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@0@Z @ 50 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &)
	?ParseElementBoolL@Input@@SAHABVTDesC8@@0@Z @ 51 NONAME ; int Input::ParseElementBoolL(class TDesC8 const &, class TDesC8 const &)
	?ParseElementHexL@Input@@SAPAVHBufC8@@ABVTDesC8@@0@Z @ 52 NONAME ; class HBufC8 * Input::ParseElementHexL(class TDesC8 const &, class TDesC8 const &)
	?ParseElementL@Input@@SAXAAPAVHBufC16@@ABVTDesC16@@1@Z @ 53 NONAME ; void Input::ParseElementL(class HBufC16 * &, class TDesC16 const &, class TDesC16 const &)
	?ParseElementL@Input@@SAXAAPAVHBufC16@@ABVTDesC16@@1AAH2@Z @ 54 NONAME ; void Input::ParseElementL(class HBufC16 * &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElementL@Input@@SAXAAPAVHBufC16@@ABVTDesC16@@1AAH@Z @ 55 NONAME ; void Input::ParseElementL(class HBufC16 * &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElementL@Input@@SAXAAPAVHBufC8@@ABVTDesC16@@1@Z @ 56 NONAME ; void Input::ParseElementL(class HBufC8 * &, class TDesC16 const &, class TDesC16 const &)
	?ParseElementL@Input@@SAXAAPAVHBufC8@@ABVTDesC16@@1AAH2@Z @ 57 NONAME ; void Input::ParseElementL(class HBufC8 * &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElementL@Input@@SAXAAPAVHBufC8@@ABVTDesC16@@1AAH@Z @ 58 NONAME ; void Input::ParseElementL(class HBufC8 * &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElementListL@Input@@SAXABVTDesC16@@00AAV?$RPointerArray@VHBufC16@@@@AAH@Z @ 59 NONAME ; void Input::ParseElementListL(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class RPointerArray<class HBufC16> &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@00@Z @ 60 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?ParseIntElement@Input@@SAIABVTDesC16@@00AAH1@Z @ 61 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@00AAH@Z @ 62 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@0@Z @ 63 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &)
	?ParseIntElement@Input@@SAIABVTDesC16@@0AAH1@Z @ 64 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@0AAH@Z @ 65 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, int &)
	?ParseIntElement@Input@@SAIABVTDesC8@@00@Z @ 66 NONAME ; unsigned int Input::ParseIntElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?ParseIntElement@Input@@SAIABVTDesC8@@00AAH1@Z @ 67 NONAME ; unsigned int Input::ParseIntElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &, int &)
	?ParseIntElement@Input@@SAIABVTDesC8@@00AAH@Z @ 68 NONAME ; unsigned int Input::ParseIntElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &)
	?PerformAction@CSyncAction@@EAEXAAVTRequestStatus@@@Z @ 69 NONAME ; void CSyncAction::PerformAction(class TRequestStatus &)
	?PerformCancel@CTestAction@@UAEXXZ @ 70 NONAME ; void CTestAction::PerformCancel(void)
	?PerformPostrequisite@CTestAction@@UAEXAAVTRequestStatus@@@Z @ 71 NONAME ; void CTestAction::PerformPostrequisite(class TRequestStatus &)
	?PerformPrerequisite@CTestAction@@UAEXAAVTRequestStatus@@@Z @ 72 NONAME ; void CTestAction::PerformPrerequisite(class TRequestStatus &)
	?ReadFileL@Input@@SAPAVHBufC8@@ABVTDesC16@@0AAVRFs@@@Z @ 73 NONAME ; class HBufC8 * Input::ReadFileL(class TDesC16 const &, class TDesC16 const &, class RFs &)
	?ReadFileL@Input@@SAPAVHBufC8@@ABVTDesC16@@AAVRFs@@@Z @ 74 NONAME ; class HBufC8 * Input::ReadFileL(class TDesC16 const &, class RFs &)
	?ReadFileLC@Input@@SAPAVHBufC8@@ABVTDesC16@@0AAVRFs@@@Z @ 75 NONAME ; class HBufC8 * Input::ReadFileLC(class TDesC16 const &, class TDesC16 const &, class RFs &)
	?ReadFileLC@Input@@SAPAVHBufC8@@ABVTDesC16@@AAVRFs@@@Z @ 76 NONAME ; class HBufC8 * Input::ReadFileLC(class TDesC16 const &, class RFs &)
	?ReportAction@CTestAction@@UAEXXZ @ 77 NONAME ; void CTestAction::ReportAction(void)
	?Reset@CTestAction@@UAEXXZ @ 78 NONAME ; void CTestAction::Reset(void)
	?RunTestsL@CTestHandler@@QAEXXZ @ 79 NONAME ; void CTestHandler::RunTestsL(void)
	?ScriptError@CTestAction@@UAE?AW4TScriptError@1@XZ @ 80 NONAME ; enum CTestAction::TScriptError CTestAction::ScriptError(void)
	?ScriptError@CTestAction@@UAEXAAVTDes16@@@Z @ 81 NONAME ; void CTestAction::ScriptError(class TDes16 &)
	?SetScriptError@CTestAction@@UAEXABW4TScriptError@1@ABVTDesC16@@@Z @ 82 NONAME ; void CTestAction::SetScriptError(enum CTestAction::TScriptError const &, class TDesC16 const &)
	?SetSharedData@CTestAction@@IAEXPAVCBase@@@Z @ 83 NONAME ; void CTestAction::SetSharedData(class CBase *)
	?SetupTestsL@CHardcodedSetup@@UAEXAAVRFs@@AAVCTestSpec@@QAUTHardcodedTests@@ABVCTestHandlerSettings@@@Z @ 84 NONAME ; void CHardcodedSetup::SetupTestsL(class RFs &, class CTestSpec &, struct THardcodedTests * const, class CTestHandlerSettings const &)
	?SetupTestsL@CScriptSetup@@UAEXAAVRFs@@AAVCTestSpec@@QAUTScriptTests@@ABVCTestHandlerSettings@@@Z @ 85 NONAME ; void CScriptSetup::SetupTestsL(class RFs &, class CTestSpec &, struct TScriptTests * const, class CTestHandlerSettings const &)
	?SharedData@CTestAction@@IBEPAVCBase@@XZ @ 86 NONAME ; class CBase * CTestAction::SharedData(void) const
	?write@Output@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 87 NONAME ; void Output::write(class TRefByValue<class TDesC16 const >, ...)
	?writeBoolL@Output@@QAEXH@Z @ 88 NONAME ; void Output::writeBoolL(int)
	?writeError@Output@@QAEXH@Z @ 89 NONAME ; void Output::writeError(int)
	?writeHex@Output@@QAEXH@Z @ 90 NONAME ; void Output::writeHex(int)
	?writeNewLine@Output@@QAEXXZ @ 91 NONAME ; void Output::writeNewLine(void)
	?writeNum@Output@@QAEXH@Z @ 92 NONAME ; void Output::writeNum(int)
	?writeOctetString@Output@@QAEXABVTDesC8@@@Z @ 93 NONAME ; void Output::writeOctetString(class TDesC8 const &)
	?writeOctetStringL@Output@@QAEXABVTDesC8@@@Z @ 94 NONAME ; void Output::writeOctetStringL(class TDesC8 const &)
	?writeSpaces@Output@@QAEXH@Z @ 95 NONAME ; void Output::writeSpaces(int)
	?writeString@Output@@QAEXABVTDesC16@@@Z @ 96 NONAME ; void Output::writeString(class TDesC16 const &)
	?writeString@Output@@QAEXABVTDesC8@@@Z @ 97 NONAME ; void Output::writeString(class TDesC8 const &)
	??0COOMTestRunnerBase@@IAE@AAVOutput@@@Z @ 98 NONAME ; COOMTestRunnerBase::COOMTestRunnerBase(class Output &)
	??0CTestRunner@@QAE@AAVOutput@@@Z @ 99 NONAME ; CTestRunner::CTestRunner(class Output &)
	??1COOMTestRunnerBase@@UAE@XZ @ 100 NONAME ; COOMTestRunnerBase::~COOMTestRunnerBase(void)
	??1CTestRunner@@UAE@XZ @ 101 NONAME ; CTestRunner::~CTestRunner(void)
	?DoCancel@CTestRunner@@EAEXXZ @ 102 NONAME ; void CTestRunner::DoCancel(void)
	?PerformActionL@COOMTestRunnerBase@@EAEHPAVCTestAction@@@Z @ 103 NONAME ; int COOMTestRunnerBase::PerformActionL(class CTestAction *)
	?PerformActionL@CTestRunner@@UAEHPAVCTestAction@@@Z @ 104 NONAME ; int CTestRunner::PerformActionL(class CTestAction *)
	?PerformPostrequisiteL@CTestRunner@@UAEHPAVCTestAction@@H@Z @ 105 NONAME ; int CTestRunner::PerformPostrequisiteL(class CTestAction *, int)
	?PerformPrerequisiteL@CTestRunner@@UAEHPAVCTestAction@@@Z @ 106 NONAME ; int CTestRunner::PerformPrerequisiteL(class CTestAction *)
	?RunError@CTestRunner@@EAEHH@Z @ 107 NONAME ; int CTestRunner::RunError(int)
	?RunL@CTestRunner@@EAEXXZ @ 108 NONAME ; void CTestRunner::RunL(void)
	?SetTestRunnerL@CTestHandler@@QAEXPAVCTestRunner@@@Z @ 109 NONAME ; void CTestHandler::SetTestRunnerL(class CTestRunner *)

